/*
 * Copyright (C)  {year} {organization}
 *
 * This file is subject to the terms and conditions of the GNU Lesser
 * General Public License v2.1. See the file LICENSE in the top level
 * directory for more details.
 */

/**
 * @ingroup     boards_{name}
 * @{{
 *
 * @file
 * @brief       Configuration of CPU peripherals for {displayed_name} board
 *
 * @author      {author_name} <{author_email}>
 */

#ifndef PERIPH_CONF_H
#define PERIPH_CONF_H

#include <stdint.h>

#include "cpu.h"
#include "periph_cpu.h"

#ifdef __cplusplus
extern "C" {{
#endif

/* put here the board peripherals definitions:
- Available clocks
- Timers
- UARTs
- PWMs
- SPIs
- I2C
- ADC
- RTC
- RTT
etc
 */

#ifdef __cplusplus
}}
#endif

#endif /* PERIPH_CONF_H */
/** @}} */
