/*
 * Copyright (C) {year} {organization}
 *
 * This file is subject to the terms and conditions of the GNU Lesser
 * General Public License v2.1. See the file LICENSE in the top level
 * directory for more details.
 */

/**
 * @ingroup     examples
 * @{{
 *
 * @file
 * @brief       {brief}
 *
 * @author      {author_name} <{author_email}>
 *
 * @}}
 */

#include <stdio.h>

int main(void)
{{
    puts("Generated RIOT example: '{name}'");
    return 0;
}}